==> jc-1.4.0.tar.gz: jasmin/ScannerUtils.h <==
// abstract class jasmin.ScannerUtils

// class file dependencies
// @dep_class c7fbb09ebd5ed4d7 jasmin_ScannerUtils
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_ScannerUtils_H_
#define _JC_jasmin_ScannerUtils_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jasmin_ScannerUtils$sub_refs	_jc_jasmin_ScannerUtils$sub_refs;
typedef struct _jc_jasmin_ScannerUtils$sub_nonrefs	_jc_jasmin_ScannerUtils$sub_nonrefs;
typedef struct _jc_jasmin_ScannerUtils$refs	_jc_jasmin_ScannerUtils$refs;
typedef struct _jc_jasmin_ScannerUtils$nonrefs	_jc_jasmin_ScannerUtils$nonrefs;
typedef struct _jc_jasmin_ScannerUtils$object	_jc_jasmin_ScannerUtils$object;

typedef const struct _jc_jasmin_ScannerUtils$vmethods	_jc_jasmin_ScannerUtils$vmethods;
typedef const struct _jc_jasmin_ScannerUtils$vtable	_jc_jasmin_ScannerUtils$vtable;
typedef const struct _jc_jasmin_ScannerUtils$vtype	_jc_jasmin_ScannerUtils$vtype;

// Constructors
extern void _jc_jasmin_ScannerUtils$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_ScannerUtils$object *);

// Static methods
extern struct _jc_java_lang_String$object *_jc_jasmin_ScannerUtils$method$convertChars$1fa61b749ba3d5cd(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jchar);
extern struct _jc_java_lang_String$object *_jc_jasmin_ScannerUtils$method$convertDots$a7f201762c760132(_jc_env *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Number$object *_jc_jasmin_ScannerUtils$method$convertInt$4114810202155a80(_jc_env *, struct _jc_java_lang_String$object *, jint);
extern struct _jc_java_lang_Number$object *_jc_jasmin_ScannerUtils$method$convertNumber$d77d4e89066a9a4f(_jc_env *, struct _jc_java_lang_String$object *);
extern _jc_object_array *_jc_jasmin_ScannerUtils$method$splitClassField$b7220c470d2b994c(_jc_env *, struct _jc_java_lang_String$object *);
extern _jc_object_array *_jc_jasmin_ScannerUtils$method$splitClassMethodSignature$018f79348bcffec5(_jc_env *, struct _jc_java_lang_String$object *);
extern _jc_object_array *_jc_jasmin_ScannerUtils$method$splitMethodSignature$fe91442fe941dfac(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_jasmin_ScannerUtils$vmethods {
};

// Vtable
struct _jc_jasmin_ScannerUtils$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_ScannerUtils$vmethods	jasmin_ScannerUtils;
};

// Vtype
struct _jc_jasmin_ScannerUtils$vtype {
	_jc_type			type;
	_jc_jasmin_ScannerUtils$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_ScannerUtils$sub_refs {
};

// Reference instance fields (object)
struct _jc_jasmin_ScannerUtils$refs {
    _jc_jasmin_ScannerUtils$sub_refs	jasmin_ScannerUtils;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_ScannerUtils$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jasmin_ScannerUtils$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_ScannerUtils$sub_nonrefs	jasmin_ScannerUtils;
};

// Object instance structure
struct _jc_jasmin_ScannerUtils$object {
	_jc_jasmin_ScannerUtils$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_ScannerUtils$vtype	*vtype;
	_jc_jasmin_ScannerUtils$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_ScannerUtils$vtype _jc_jasmin_ScannerUtils$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_ScannerUtils, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_ScannerUtils$class_object;

#endif	/* _JC_jasmin_ScannerUtils_H_ */

==> jc-1.4.6.tar.gz: jasmin/ScannerUtils.h <==
// abstract class jasmin.ScannerUtils

// class file dependencies
// @dep_class c7fbb09ebd5ed4d7 jasmin_ScannerUtils
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jasmin_ScannerUtils_H_
#define _JC_jasmin_ScannerUtils_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Number$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jasmin_ScannerUtils$sub_refs	_jc_jasmin_ScannerUtils$sub_refs;
typedef struct _jc_jasmin_ScannerUtils$sub_nonrefs	_jc_jasmin_ScannerUtils$sub_nonrefs;
typedef struct _jc_jasmin_ScannerUtils$refs	_jc_jasmin_ScannerUtils$refs;
typedef struct _jc_jasmin_ScannerUtils$nonrefs	_jc_jasmin_ScannerUtils$nonrefs;
typedef struct _jc_jasmin_ScannerUtils$object	_jc_jasmin_ScannerUtils$object;

typedef const struct _jc_jasmin_ScannerUtils$vmethods	_jc_jasmin_ScannerUtils$vmethods;
typedef const struct _jc_jasmin_ScannerUtils$vtable	_jc_jasmin_ScannerUtils$vtable;
typedef const struct _jc_jasmin_ScannerUtils$vtype	_jc_jasmin_ScannerUtils$vtype;

// Constructors
extern void _jc_jasmin_ScannerUtils$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_jasmin_ScannerUtils$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_String$object *_jc_jasmin_ScannerUtils$method$convertChars$1fa61b749ba3d5cd(_jc_env *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, jchar) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_jasmin_ScannerUtils$method$convertDots$a7f201762c760132(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_jasmin_ScannerUtils$method$convertInt$4114810202155a80(_jc_env *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Number$object *_jc_jasmin_ScannerUtils$method$convertNumber$d77d4e89066a9a4f(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_jasmin_ScannerUtils$method$splitClassField$b7220c470d2b994c(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_jasmin_ScannerUtils$method$splitClassMethodSignature$018f79348bcffec5(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_jasmin_ScannerUtils$method$splitMethodSignature$fe91442fe941dfac(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_jasmin_ScannerUtils$vmethods {
};

// Vtable
struct _jc_jasmin_ScannerUtils$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jasmin_ScannerUtils$vmethods	jasmin_ScannerUtils;
};

// Vtype
struct _jc_jasmin_ScannerUtils$vtype {
	_jc_type			type;
	_jc_jasmin_ScannerUtils$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jasmin_ScannerUtils$sub_refs {
};

// Reference instance fields (object)
struct _jc_jasmin_ScannerUtils$refs {
    _jc_jasmin_ScannerUtils$sub_refs	jasmin_ScannerUtils;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jasmin_ScannerUtils$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jasmin_ScannerUtils$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jasmin_ScannerUtils$sub_nonrefs	jasmin_ScannerUtils;
};

// Object instance structure
struct _jc_jasmin_ScannerUtils$object {
	_jc_jasmin_ScannerUtils$refs	refs[0];
	_jc_word		lockword;
	_jc_jasmin_ScannerUtils$vtype	*vtype;
	_jc_jasmin_ScannerUtils$nonrefs	nonrefs;
};

// Type structure
extern _jc_jasmin_ScannerUtils$vtype _jc_jasmin_ScannerUtils$type;

// Array types class info structures
_JC_DECL_ARRAYS(jasmin_ScannerUtils, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jasmin_ScannerUtils$class_object;

#endif	/* _JC_jasmin_ScannerUtils_H_ */
